local mod = ExtraCD
local L = LibStub("AceLocale-3.0"):GetLocale("ExtraCD")
local LSM = LibStub("LibSharedMedia-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local ecddb

local function setOption(info, value)
	local name = info[#info]
	ecddb[name] = value
	mod:ResetAllIcons()
end

local function getOption(info)
	local name = info[#info]
	return ecddb[name]
end

function mod:ShowConfig()
	InterfaceOptionsFrame_OpenToCategory(GetAddOnMetadata("ExtraCD", "Title"))
end

function mod:AddOption(name, pName, keyName)
	return AceConfigDialog:AddToBlizOptions("ExtraCD", name, pName, keyName)
end

function mod:ChangeProfile()
	ecddb = self.db1.profile
end

function mod:OnOptionRefresh()

end

function mod:OnOptionCreate()
	
	ecddb = self.db1.profile	
	self.options = {
		type = "group",
		name = GetAddOnMetadata("ExtraCD", "Title"),
		args = {
			general = {
				type = "group",
				name = "General",
				get = getOption,
				set = setOption,
				order = 1,
				args = {
					ecddesc = {
						type = "description",
						order = 0,
						name = GetAddOnMetadata("ExtraCD", "Notes"),
					},
					talent = {
						name = L["Talent icd"],
						desc = L["Scan and show internal cooldown of player's talent."],
						type = "toggle",
						order = 100,
						width = "full",
					},
					enchant = {
						name = L["Enchant icd"],
						desc = L["Scan and show internal cooldown of player's enchant."],
						type = "toggle",
						order = 200,
						width = "full",
					},
					item = {
						name = L["Trinket icd"],
						desc = L["Scan and show internal cooldown of player's trinket."],
						type = "toggle",
						order = 300,
						width = "full",
					},
					itemset = {
						name = L["Item Set icd"],
						desc = L["Scan and show internal cooldown of player's item set."],
						type = "toggle",
						order = 301,
						width = "full",
					},
					lock = {
						name = L["Lock frame"],
						desc = L["Set the frame locked."],
						type = "toggle",
						order = 305,
						width = "full",
					},
					combat = {
						name = L["Combat only"],
						desc = L["Show the icon only in combat."],
						type = "toggle",
						order = 306,
						width = "full",
					},
					glow = {
						name = L["Show glow"],
						desc = L["Show glow around the icon not cooldowns."],
						type = "toggle",
						order = 308,
						width = "full",
					},
					tip = {
						name = L["Show tooltip"],
						desc = L["Show tooltip for the icons."],
						type = "toggle",
						order = 309,
						width = "full",
					},
					rowmax = {
						name = L["Icons each row"],
						desc = L["Set the icons in each row"],
						type = "range",
						max = 20,
						min = 1,
						step = 1,
						order = 333,
					},
					showtext = {
						name = L["Cooldown text"],
						desc = L["Show or hide the cooldown text."],
						type = "toggle",
						order = 310,
					},
					NewLine1 = {
						type= 'description',
						order = 311,
						name= '',
						width = "full",
					},
					textsize = {
						name = L["Text size"],
						desc = L["Set the cooldown text size"],
						type = "range",
						max = 30,
						min = 12,
						step = 1,
						order = 320,
						disabled = function() return not ecddb.showtext end,						
					},
					textfont = {
						name = L["Text font"],
						desc = L["Set the font of the text"],
						type = "select",
						dialogControl = 'LSM30_Font',
						values = LSM:HashTable("font"),
						order = 321,
					},
					iconinterval = {
						name = L["Icon interval"],
						desc = L["Set the interval size between icons"],
						type ="range",
						max = 20,
						min = 0,
						step = 1,
						order = 323,
					},
					iconsize = {
						name = L["Icon size"],
						desc = L["Set the icon size"],
						type = "range",
						max = 60,
						min = 1,
						step = 1,
						order = 330,					
					},
					blacklist = {
						name = L["Blacklist"],
						desc = L["When you crtl+right click at the icon, it will be added in the blacklist. And select any item in this list will remove it from list and show it again."],
						type = "select",
						values = ecddb.blacklist,
						get = function() return false end,
						set = function(info , value)  ecddb.blacklist[value] = nil mod:ResetAllIcons() end, 
						order = 350,
					},
					iconborder = {
						name = L["Icon border"],
						desc = L["Set the icon border"],
						type = "select",
						dialogControl = 'LSM30_Border',
						values = LSM:HashTable("border"),
						order = 340,
					},
				},
			},	
			advance = {
				type = "group",
				name = "Advance",
				get = getOption,
				set = setOption,
				args = {
					data = {
						type = "group",
						name = "Data",
						get = getOption,
						set = setOption,
						args = {
							addCustom = {
								type = "execute",
								name = "Add New CDs",
								order = 10,
							},
							dataReset = {
								type = "execute",
								name = "Reset Original Data",
								confirm = true,
								confirmText = "Are you sure to reset all addon original data(your custom data and proc test will not be changed)?",
								order = 100,
							},
							dataDelete = {
								type = "execute",
								name = "Delete Custom Data",
								confirm = true,
								confirmText = "Are you sure to delete all custom data(the addon original data and proc test will not be changed)?",
								order = 200,
							},
						}
					},
					procTest = {
						type = "group",
						name = "Proc Test",
						get = getOption,
						set = setOption,
						args = {
							addCustom = {
								type = "execute",
								name = "Add New CDs",
								order = 10,
							},
						}
					}
				}
			},
			
		}
	}
	self.options.args.profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db1)
	self.options.args.profiles.order = -1
	LibStub("AceConfig-3.0"):RegisterOptionsTable("ExtraCD", ExtraCD.options)
	self:AddOption(GetAddOnMetadata("ExtraCD", "Title"), nil, "general")
	
	-- need localization 
	self:AddOption("Advance", "ExtraCD", "advance")
	-- end
	
	self:AddOption(L["Profiles"], "ExtraCD", "profiles")
end